<?php

/*
 * This file is part of Monsieur Biz' Search plugin for Sylius.
 *
 * (c) Monsieur Biz <sylius@monsieurbiz.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

declare(strict_types=1);

namespace MonsieurBiz\SyliusSearchPlugin\EventListener;

use MonsieurBiz\SyliusSearchPlugin\Model\Document\Index\IndexerInterface;
use MonsieurBiz\SyliusSearchPlugin\Model\Documentable\DocumentableInterface;
use Symfony\Component\EventDispatcher\GenericEvent;
use Webmozart\Assert\Assert;

final class DocumentListener
{
    private IndexerInterface $documentIndexer;

    public function __construct(IndexerInterface $documentIndexer)
    {
        $this->documentIndexer = $documentIndexer;
    }

    public function saveDocument(GenericEvent $event): void
    {
        $subject = $event->getSubject();
        Assert::isInstanceOf($subject, DocumentableInterface::class);

        $this->documentIndexer->indexOne($subject);
    }

    public function deleteDocument(GenericEvent $event): void
    {
        $subject = $event->getSubject();
        Assert::isInstanceOf($subject, DocumentableInterface::class);

        $this->documentIndexer->removeOne($subject);
    }
}
