<?php

/*
 * This file is part of Monsieur Biz' Search plugin for Sylius.
 *
 * (c) Monsieur Biz <sylius@monsieurbiz.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

declare(strict_types=1);

namespace MonsieurBiz\SyliusSearchPlugin\Model\Document;

class Filter implements FilterInterface
{
    private string $code;

    private string $label;

    /** @var FilterValueInterface[] */
    private array $values = [];

    private int $count;

    /**
     * Filter constructor.
     */
    public function __construct(string $code, string $label, int $count)
    {
        $this->code = $code;
        $this->label = $label;
        $this->count = $count;
    }

    public function getCode(): string
    {
        return $this->code;
    }

    public function getLabel(): string
    {
        return $this->label;
    }

    /**
     * @return FilterValueInterface[]
     */
    public function getValues(): array
    {
        return $this->values;
    }

    public function addValue(FilterValueInterface $value): void
    {
        $this->values[] = $value;
    }

    public function removeValue(FilterValueInterface $value): void
    {
        $value = array_search($value, $this->values);
        if (false === $value) {
            return;
        }
        unset($this->values[$value]);
        $this->values = array_values($this->values);
    }

    public function getCount(): int
    {
        return $this->count;
    }
}
